%{!?kernel_version: %{expand: %%define kernel_version %(uname -r| perl -pe 's/-[a-zA-Z].*?$//g')}}
%{!?kversionreltag: %{expand: %%define kversionreltag %(echo %{kernel_version} |sed -e 's/-/./g')}}
%{!?type: %{expand: %%define type %(uname -r| perl -pe 's/.*-//g')}}

%define releasetag %{kversionreltag}.%{type}
%define kernel_dir %{kernel_version}-%{type}
%define kmp_version %version

# Keep the modKey def identical to that in util.sh-PMWV.*
%define modKey 'PMWV|%{type}|vmci'
%define vmwDB /usr/lib/vmware-tools/moduleScripts/vmci/vmware-db.pl --os=linux,sle,9
%define vmwPMWV /usr/lib/vmware-tools/moduleScripts/vmci/vmware-pmwv.pl --os=linux,sle,9 --release=%{kernel_dir} --build 2560490 --modKey %{modKey}

Name:         vmware-tools-vmci
BuildRequires: kernel-source kernel-syms
Vendor:       VMware
License:      GPL
Group:        System/Kernel
Summary:      Contains the source needed to build the vmci kernel module package (kmp) for the running kernel.
Epoch:        0
Version:      1.0.15.0
Release:      5.sles9
BuildRoot:    %{_tmppath}/%{name}-%{version}-build
Source1:      vmci-configModule.tar.gz

Source0:      vmci.tar

%prep
%setup -n vmci-only

%build
make clean
make

# NOTE: RHEL 4 has MODVERSIONS enabled but does not generate the module.symvers
#       file we would need in order to properly propagate symbol versions
#       in-between interdependent kernel modules.  See bug 568405 for more info.
if [ "vmci" = "vsock" -o "vmci" = "vmhgfs" ]; then
   echo
   echo
   echo "Please ignore the \"VMCI_ ... undefined!\" warnings generated by the build system."
   echo "The vmci module will load and function properly despite those warnings."
   echo
   echo
fi

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
install -m 644 -D ../vmci.o $RPM_BUILD_ROOT/lib/modules/%{kernel_dir}/extra/vmware/vmci.ko
# Install common files
cd $RPM_BUILD_ROOT && tar xzf %{SOURCE1}

%description
 This package enables you to build binary kernel module packages (kmps) for vmci.  The vmci device is a virtual PCI device that provides high-speed communication between the virtual machine and its hypervisor or host applications as well as between virtual machines that reside on the same host. Vmci does not rely on guest networking.

%package common
Summary:      Contains the common files used by all the vmci kernel module packages (kmps).
Group:        System/Kernel
Requires:     perl
Requires:     vmware-tools-foundation >= 0:8.6.0
Release:      5.sles9
Version:      9.0.15

%description common
 This package contains the common system configuration and scripts responsible for loading the vmci kernel module.  The vmci device is a virtual PCI device that provides high-speed communication between the virtual machine and its hypervisor or host applications as well as between virtual machines that reside on the same host. Vmci does not rely on guest networking.

%package kmp-%{type}
Summary:      The vmci kernel module built for the %{kernel_version} kernel.
Group:        System/Kernel
Requires:     vmware-tools-vmci-common
Requires:     vmware-tools-foundation >= 0:8.6.0
Provides:     vmware-tools-vmci-kmp
Release:      %{kversionreltag}.5.sles9


%description kmp-%{type}
 This package contains a pre-compiled vmci module for use with the %{kernel_version} kernel.   The vmci device is a virtual PCI device that provides high-speed communication between the virtual machine and its hypervisor or host applications as well as between virtual machines that reside on the same host. Vmci does not rely on guest networking.

%pre kmp-%{type}
# Deconfigure if upgrading
if [ $1 -gt 1 ]; then
   kmodType=`uname -r | sed -e 's/.*-//g'`
   if [ "$kmodType" = "%{type}" ]; then
      /etc/init.d/vmci stop || true
   fi

   %{vmwPMWV} --rpmSection=Postun
fi

# Configure
%{vmwPMWV} --rpmSection=Pre

%post common
# Deconfigure if upgrading
if [ $1 -gt 1 ]; then
   if [ -e /etc/init.d/vmci ]; then
      /sbin/insserv -r vmci /dev/null 2>&1
   fi
   /usr/lib/vmware-tools/moduleScripts/vmci/vmware-deconfig.pl --os=linux,sle,9 --toDeconfigure=vmci
   /usr/lib/vmware-tools/moduleScripts/vmci/vmware-db.pl --os=linux,sle,9 --dbDelAnswer VMCI_NAME
fi

# Configure
/usr/lib/vmware-tools/moduleScripts/vmci/vmware-db.pl --os=linux,sle,9 --dbAddAnswer VMCI_NAME,vmci
/usr/lib/vmware-tools/moduleScripts/vmci/vmware-config.pl --os=linux,sle,9 --toConfigure=vmci
if [ -e /etc/init.d/vmci ]; then
   /sbin/insserv -f vmci >/dev/null 2>&1
fi

%post kmp-%{type}
# Configure
# Invoke the PMWV Post Section
%{vmwPMWV} --rpmSection=Post --baseMod=/lib/modules/%{kernel_dir}/extra/vmware/vmci.ko

# If the type matches, start the init script
kmodType=`uname -r | sed -e 's/.*-//g'`
if [ "$kmodType" = "%{type}" ]; then
   /etc/init.d/vmci start || true
fi

%preun common
# Only deconfigure if we are erasing the package here... not if we are upgrading.
if [ $1 = 0 ]; then
   if [ -e /etc/init.d/vmci ]; then
      /sbin/insserv -r vmci /dev/null 2>&1
   fi
   /usr/lib/vmware-tools/moduleScripts/vmci/vmware-deconfig.pl --os=linux,sle,9 --toDeconfigure=vmci
   /usr/lib/vmware-tools/moduleScripts/vmci/vmware-db.pl --os=linux,sle,9 --dbDelAnswer VMCI_NAME
fi

%preun kmp-%{type}
# Only deconfigure if we are erasing the package here... not if we are upgrading.
if [ $1 = 0 ]; then
   kmodType=`uname -r | sed -e 's/.*-//g'`
   if [ "$kmodType" = "%{type}" ]; then
      /etc/init.d/vmci stop || true
   fi
fi

%postun kmp-%{type}
# Only deconfigure if we are erasing the package here... not if we are upgrading.
if [ $1 = 0 ]; then
   %{vmwPMWV} --rpmSection=Postun
fi

%files common
%defattr(-, root, root, -)
/usr/lib/vmware-tools/moduleScripts/vmci/vmware-pmwv.pl
/usr/lib/vmware-tools/moduleScripts/vmci/vmware-deconfig.pl
/usr/lib/vmware-tools/moduleScripts/vmci/vmware-db.pl
/usr/lib/vmware-tools/moduleScripts/vmci/vmware-config.pl
/etc/init.d/vmci

%files kmp-%{type}
%defattr(-, root, root, -)
/lib/modules/%{kernel_dir}/extra/vmware/vmci.ko
